-- globals
local ADDON =  "SlashParty";
local VERSION = GetAddOnMetadata(ADDON, "Version") or "Unknown Verson";
local TITLE = GetAddOnMetadata(ADDON, "Title") or "UnKnown Title";

realm = GetRealmName("player");
player = GetUnitName("player");


local frame = CreateFrame("FRAME", "SlashPartyFrame");
frame:RegisterEvent("ADDON_LOADED");


function SlashPartyFrame_OnEvent(frame, event, ...)

	if event == "ADDON_LOADED" then
		if not SlashPartyData then
			SlashPartyData = {};
		end
	end

end

SlashCmdList['SlashLeave_SLASHCMD'] = function()
	LeaveParty();

	local numBattlefields = GetMaxBattlefieldID();
	if numBattlefields then
		for i = 1,numBattlefields do
			local status, mapName, instanceID, bracketMin, bracketMax, teamSize, registeredMatch = GetBattlefieldStatus(i);
			if status == "active" then
				LeaveBattlefield();
			end
		end
	end
	
end
SLASH_SlashLeave_SLASHCMD1 = '/leave';
SLASH_SlashLeave_SLASHCMD2 = '/lv';


SlashCmdList['SlashMakeToggleChallenge_SLASHCMD'] = function()
	if GetNumGroupMembers() and UnitIsGroupLeader("player") then
		if IsInRaid() then
			ConvertToParty();
		end
		if GetDungeonDifficultyID() == 8 then
			SetDungeonDifficultyID(2);	
		else
			SetDungeonDifficultyID(8);	
		end
	else
		print("You must be the group leader to convert to/from challenge mode difficulty.");
	end
end
SLASH_SlashMakeToggleChallenge_SLASHCMD1 = '/togglechallenge';
SLASH_SlashMakeToggleChallenge_SLASHCMD2 = '/challenge';

SlashCmdList['SlashMakeToggleHeroic_SLASHCMD'] = function()
	if GetNumGroupMembers() and UnitIsGroupLeader("player") then
		if IsInRaid() then
			if GetRaidDifficulty() == 1 then
				SetRaidDifficulty(3);
			end
			if GetRaidDifficulty() == 2 then
				SetRaidDifficulty(4);
			end
			if GetRaidDifficulty() == 3 then
				SetRaidDifficulty(1);
			end
			if GetRaidDifficulty() == 4 then
				SetRaidDifficulty(2);
			end
		else
			if GetDungeonDifficultyID() == 2 then
				SetDungeonDifficultyID(1);	
			else
				SetDungeonDifficultyID(2);
			end
		end
	else
		print("You must be the group leader to convert to/from heroic difficulty.");
	end
end
SLASH_SlashMakeToggleHeroic_SLASHCMD1 = '/toggleheroic';
SLASH_SlashMakeToggleHeroic_SLASHCMD2 = '/heroic';

SlashCmdList['SlashMakeRaid_SLASHCMD'] = function()
	if GetNumGroupMembers() and UnitIsGroupLeader("player") then
		if IsInRaid() then
			ConvertToParty();
		else
			ConvertToRaid();
		end
	else
		print("You must be the group leader to convert to/from raid.");
	end
end
SLASH_SlashMakeRaid_SLASHCMD1 = '/makeraid';
SLASH_SlashMakeRaid_SLASHCMD2 = '/mraid';
SLASH_SlashMakeRaid_SLASHCMD3 = '/makeparty';
SLASH_SlashMakeRaid_SLASHCMD4 = '/mparty';

SlashCmdList['SlashMakePass_SLASHCMD'] = function()
	if GetNumGroupMembers() and not UnitIsGroupLeader("player") then
		SetOptOutOfLoot(true);
	else
		print("Party leader cannot pass on loot.");
	end
end
SLASH_SlashMakePass_SLASHCMD1 = '/passloot';
SLASH_SlashMakePass_SLASHCMD2 = '/ploot';

SlashCmdList['SlashReset_SLASHCMD'] = function()
	if GetNumGroupMembers() and UnitIsGroupLeader("player") then
		ResetInstances();
		print("Reset Command Sent.");
	end
end
SLASH_SlashReset_SLASHCMD1 = '/reset';

SlashCmdList['SlashTele_SLASHCMD'] = function()
	if IsInInstance() then
		LFGTeleport(true);
	else
		LFGTeleport();
	end
end
SLASH_SlashTele_SLASHCMD1 = '/tele';

SlashCmdList['SlashSetRaid_SLASHCMD'] = function(data)
	if GetNumGroupMembers() and UnitIsGroupLeader("player") then
		local flag1, flag2 = strsplit(" ", data, 2);

		if not flag1 then flag1 = "null" end
		if not flag2 then flag2 = "null" end

		if flag1 == "null" then
			print("Invalid Usage: Try:");
			print("/sraid 10");
			print("/sraid 10h");
			print("/sraid 25");
			print("/sraid 25h");
			return;
		end

		if not IsInRaid() then
			ConvertToRaid();
		end

		if data == "10" then
			SetRaidDifficulty(1);
		end
		if data == "25" then
			SetRaidDifficulty(2);
		end
		if data == "10h" then
			SetRaidDifficulty(3);
		end
		if data == "25h" then
			SetRaidDifficulty(4);
		end

	end
end
SLASH_SlashSetRaid_SLASHCMD1 = '/setraid';	
SLASH_SlashSetRaid_SLASHCMD2 = '/sraid';	

SlashCmdList['SlashSetLoot_SLASHCMD'] = function(data)
	if GetNumGroupMembers() and UnitIsGroupLeader("player") then
		local theshold = nil;
		local method = nil;

		local flag1, flag2 = strsplit(" ", data, 2);

		if not flag1 then flag1 = "null" end
		if not flag2 then flag2 = "null" end

		if flag1 == "null" then
			print("Invalid Usage: Try:");
			print("/sloot green");
			print("/sloot blue");
			print("/sloot epic");
			print("/sloot legend");
			print("--  or --");
			print("/sloot group");
			print("/sloot ffa");
			print("/sloot master");
			print("/sloot need");
			print("/sloot round");
			return;
		end

		if 	flag1 == "uncommon" or 
			flag2 == "uncommon" or
			flag1 == "green" or 
			flag2 == "green" then
			threshold = 2;
		end

		if 	flag1 == "rare" or 
			flag2 == "rare" or
			flag1 == "blue" or 
			flag2 == "blue" then
			threshold = 3;
		end

		if 	flag1 == "epic" or 
			flag2 == "epic" or
			flag1 == "purple" or 
			flag2 == "purple" then
			threshold = 4;
		end

		if 	flag1 == "legendary" or 
			flag2 == "legendary" or
			flag2 == "legend" or
			flag1 == "legend" or 
			flag1 == "orange" or 
			flag2 == "orange" then
			threshold = 5;
		end

		if flag1 == "group" or flag2 == "group" then
			method = "group";
		end

		if flag1 == "ffa" or flag2 == "ffa" then
			method = "freeforall";
		end

		if flag1 == "master" or flag2 == "master" then
			method = "master";
		end

		if flag1 == "need" or flag2 == "need" then
			method = "needbeforegreed";
		end

		if flag1 == "round" or flag2 == "round" then
			method = "roundrobin";
		end

		if threshold then SetLootThreshold(tonumber(threshold)); end
		if method then SetLootMethod(method,UnitName("Player")); end
		
	else
		print("You must be the leader of a group to set loot.");
	end
end
SLASH_SlashSetLoot_SLASHCMD1 = '/setloot';
SLASH_SlashSetLoot_SLASHCMD2 = '/sloot';
		
SlashCmdList['SlashSetGroup_SLASHCMD'] = function(data)
	if GetNumGroupMembers() and UnitIsGroupLeader("player") then
		local theshold = nil;
		local method = nil;

		local flag1, flag2 = strsplit(" ", data, 2);

		if not flag1 then flag1 = "null" end
		if not flag2 then flag2 = "null" end

		if flag1 == "null" then
			print("Invalid Usage: Try:");
			print("/sgroup normal");
			print("/sgroup heroic");
			print("/sgroup challenge");
			return;
		end

		if IsInRaid() then
			ConvertToParty();
		end

		if flag1 == "normal" then
			SetDungeonDifficultyID(1);	
		end
		if flag1 == "heroic" then
			SetDungeonDifficultyID(2);	
		end
		if flag1 == "challenge" then
			SetDungeonDifficultyID(8);	
		end

	else
		print("You must be the leader of a group to set group difficulty.");
	end
end
SLASH_SlashSetGroup_SLASHCMD1 = '/setgroup';
SLASH_SlashSetGroup_SLASHCMD2 = '/sgroup';

SlashCmdList['SlashParty_SLASHCMD'] = function(data)
	print(ADDON.." "..VERSION.." Syntax Help:");
	if not data == "" then
		print("-- All Players --");
		print("  /lv    | leaves the group");
		print("  /tele  | teleports in/out of dungeon when in a LFD group.");
		print("  /ploot | set Pass On Loot to Yes");
		print("  ");
		print("-- Group Leaders --");
		print("  /mraid     | Converts the party to/from raid.");
		print("  /sloot     | sets loot type and threshold.");
		print("  /sgroup    | sets group difficulty to normale, heroic or challenge modes");
		print("  /sraid     | Sets raid difficulty to 10, 25, 10h, 25h");
		print("  /heroic    | toggles the current raid/dungeon difficulty between heroic/normal modes");
		print("  /challenge | toggles the current dungeon difficulty etween heroic/challenge modes");
	else
		print("-- All Players --");
		print("  /party help");
		print("  /lv aka /leave");
		print("  /tele");
		print("  /ploot aka /passloot");
		print("  ");
		print("-- Party Leaders --");
		print("  /mraid aka /makeraid");
		print("  /sloot aka /setloot");
		print("  /sgroup aka /setgroup");
		print("  /sraid aka /setraid");
		print("  /heroic aka /toggleheroic");
		print("  /challenge aka /togglechallenge");
	end
end
SLASH_SlashParty_SLASHCMD1 = '/slashparty';
SLASH_SlashParty_SLASHCMD2 = '/party';

print(ADDON.." "..VERSION.." Loaded! Type /party for syntax help.")
